==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/TOOLSADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TOOLSADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TOOLSADJUSTMENTS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT0" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT6" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT7" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT8" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT9" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TOOLSADJUSTMENTS_Type", propOrder = {
    "toolsadjustment0",
    "toolsadjustment1",
    "toolsadjustment2",
    "toolsadjustment3",
    "toolsadjustment4",
    "toolsadjustment5",
    "toolsadjustment6",
    "toolsadjustment7",
    "toolsadjustment8",
    "toolsadjustment9"
})
public class TOOLSADJUSTMENTS_Type {

    @XmlElement(name = "TOOLSADJUSTMENT0")
    protected USERDEFINEDCODEID_Type toolsadjustment0;
    @XmlElement(name = "TOOLSADJUSTMENT1")
    protected USERDEFINEDCODEID_Type toolsadjustment1;
    @XmlElement(name = "TOOLSADJUSTMENT2")
    protected USERDEFINEDCODEID_Type toolsadjustment2;
    @XmlElement(name = "TOOLSADJUSTMENT3")
    protected USERDEFINEDCODEID_Type toolsadjustment3;
    @XmlElement(name = "TOOLSADJUSTMENT4")
    protected USERDEFINEDCODEID_Type toolsadjustment4;
    @XmlElement(name = "TOOLSADJUSTMENT5")
    protected USERDEFINEDCODEID_Type toolsadjustment5;
    @XmlElement(name = "TOOLSADJUSTMENT6")
    protected USERDEFINEDCODEID_Type toolsadjustment6;
    @XmlElement(name = "TOOLSADJUSTMENT7")
    protected USERDEFINEDCODEID_Type toolsadjustment7;
    @XmlElement(name = "TOOLSADJUSTMENT8")
    protected USERDEFINEDCODEID_Type toolsadjustment8;
    @XmlElement(name = "TOOLSADJUSTMENT9")
    protected USERDEFINEDCODEID_Type toolsadjustment9;

    /**
     * Gets the value of the toolsadjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT0() {
        return toolsadjustment0;
    }

    /**
     * Sets the value of the toolsadjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment0 = value;
    }

    /**
     * Gets the value of the toolsadjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT1() {
        return toolsadjustment1;
    }

    /**
     * Sets the value of the toolsadjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment1 = value;
    }

    /**
     * Gets the value of the toolsadjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT2() {
        return toolsadjustment2;
    }

    /**
     * Sets the value of the toolsadjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment2 = value;
    }

    /**
     * Gets the value of the toolsadjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT3() {
        return toolsadjustment3;
    }

    /**
     * Sets the value of the toolsadjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment3 = value;
    }

    /**
     * Gets the value of the toolsadjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT4() {
        return toolsadjustment4;
    }

    /**
     * Sets the value of the toolsadjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment4 = value;
    }

    /**
     * Gets the value of the toolsadjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT5() {
        return toolsadjustment5;
    }

    /**
     * Sets the value of the toolsadjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment5 = value;
    }

    /**
     * Gets the value of the toolsadjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT6() {
        return toolsadjustment6;
    }

    /**
     * Sets the value of the toolsadjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment6 = value;
    }

    /**
     * Gets the value of the toolsadjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT7() {
        return toolsadjustment7;
    }

    /**
     * Sets the value of the toolsadjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment7 = value;
    }

    /**
     * Gets the value of the toolsadjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT8() {
        return toolsadjustment8;
    }

    /**
     * Sets the value of the toolsadjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment8 = value;
    }

    /**
     * Gets the value of the toolsadjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT9() {
        return toolsadjustment9;
    }

    /**
     * Sets the value of the toolsadjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment9 = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/TOOLSADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TOOLSADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="TOOLSADJUSTMENTS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT0" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT1" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT2" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT3" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT4" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT5" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT6" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT7" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT8" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOOLSADJUSTMENT9" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TOOLSADJUSTMENTS_Type", propOrder = {
    "toolsadjustment0",
    "toolsadjustment1",
    "toolsadjustment2",
    "toolsadjustment3",
    "toolsadjustment4",
    "toolsadjustment5",
    "toolsadjustment6",
    "toolsadjustment7",
    "toolsadjustment8",
    "toolsadjustment9"
})
public class TOOLSADJUSTMENTS_Type {

    @XmlElement(name = "TOOLSADJUSTMENT0")
    protected USERDEFINEDCODEID_Type toolsadjustment0;
    @XmlElement(name = "TOOLSADJUSTMENT1")
    protected USERDEFINEDCODEID_Type toolsadjustment1;
    @XmlElement(name = "TOOLSADJUSTMENT2")
    protected USERDEFINEDCODEID_Type toolsadjustment2;
    @XmlElement(name = "TOOLSADJUSTMENT3")
    protected USERDEFINEDCODEID_Type toolsadjustment3;
    @XmlElement(name = "TOOLSADJUSTMENT4")
    protected USERDEFINEDCODEID_Type toolsadjustment4;
    @XmlElement(name = "TOOLSADJUSTMENT5")
    protected USERDEFINEDCODEID_Type toolsadjustment5;
    @XmlElement(name = "TOOLSADJUSTMENT6")
    protected USERDEFINEDCODEID_Type toolsadjustment6;
    @XmlElement(name = "TOOLSADJUSTMENT7")
    protected USERDEFINEDCODEID_Type toolsadjustment7;
    @XmlElement(name = "TOOLSADJUSTMENT8")
    protected USERDEFINEDCODEID_Type toolsadjustment8;
    @XmlElement(name = "TOOLSADJUSTMENT9")
    protected USERDEFINEDCODEID_Type toolsadjustment9;

    /**
     * Gets the value of the toolsadjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT0() {
        return toolsadjustment0;
    }

    /**
     * Sets the value of the toolsadjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment0 = value;
    }

    /**
     * Gets the value of the toolsadjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT1() {
        return toolsadjustment1;
    }

    /**
     * Sets the value of the toolsadjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment1 = value;
    }

    /**
     * Gets the value of the toolsadjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT2() {
        return toolsadjustment2;
    }

    /**
     * Sets the value of the toolsadjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment2 = value;
    }

    /**
     * Gets the value of the toolsadjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT3() {
        return toolsadjustment3;
    }

    /**
     * Sets the value of the toolsadjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment3 = value;
    }

    /**
     * Gets the value of the toolsadjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT4() {
        return toolsadjustment4;
    }

    /**
     * Sets the value of the toolsadjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment4 = value;
    }

    /**
     * Gets the value of the toolsadjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT5() {
        return toolsadjustment5;
    }

    /**
     * Sets the value of the toolsadjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment5 = value;
    }

    /**
     * Gets the value of the toolsadjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT6() {
        return toolsadjustment6;
    }

    /**
     * Sets the value of the toolsadjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment6 = value;
    }

    /**
     * Gets the value of the toolsadjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT7() {
        return toolsadjustment7;
    }

    /**
     * Sets the value of the toolsadjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment7 = value;
    }

    /**
     * Gets the value of the toolsadjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT8() {
        return toolsadjustment8;
    }

    /**
     * Sets the value of the toolsadjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment8 = value;
    }

    /**
     * Gets the value of the toolsadjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getTOOLSADJUSTMENT9() {
        return toolsadjustment9;
    }

    /**
     * Sets the value of the toolsadjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setTOOLSADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.toolsadjustment9 = value;
    }

}
